@@ -46,15 +46,16 @@ async def wait_for_server(host, port, timeout=10):
 
 
 async def start_server(configs: Config):
-    assert configs.host is not None
-    assert configs.port is not None
     assert configs.db_path is not None
-    if not os.path.isdir(configs.db_path):
+    if not os.path.isdir(os.path.expanduser(configs.db_path)):
         print(
             f"Creating database at {os.path.expanduser('~/.local/share/vectorcode/chromadb/')}.",
             file=sys.stderr,
         )
     env = os.environ.copy()
+    with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as s:
+        s.bind(("", 0))  # OS selects a free ephemeral port
+        configs.port = int(s.getsockname()[1])
     env.update({"ANONYMIZED_TELEMETRY": "False"})
     process = subprocess.Popen(
         [
@@ -63,7 +64,7 @@ async def start_server(configs: Config):
             "chromadb.cli.cli",
             "run",
             "--host",
-            configs.host,
+            "localhost",
             "--port",
             str(configs.port),
             "--path",
@@ -103,7 +104,9 @@ def get_client(configs: Config) -> Coroutine[Any, Any, AsyncClientAPI]:
 def get_collection_name(full_path: str) -> str:
     full_path = str(expand_path(full_path, absolute=True))
     hasher = hashlib.sha256()
-    hasher.update(f"{os.environ['USER']}@{socket.gethostname()}:{full_path}".encode())
+    hasher.update(
+        f"{os.environ.get('USER', os.environ.get('USERNAME', 'DEFAULT_USER'))}@{socket.gethostname()}:{full_path}".encode()
+    )
     collection_id = hasher.hexdigest()[:63]
     return collection_id
 
@@ -130,14 +133,17 @@ async def make_or_get_collection(client: AsyncClientAPI, configs: Config):
             "path": full_path,
             "hostname": socket.gethostname(),
             "created-by": "VectorCode",
-            "username": os.environ["USER"],
+            "username": os.environ.get(
+                "USER", os.environ.get("USERNAME", "DEFAULT_USER")
+            ),
             "embedding_function": configs.embedding_function,
         },
         embedding_function=get_embedding_function(configs),
     )
     if (
         not collection.metadata.get("hostname") == socket.gethostname()
-        or not collection.metadata.get("username") == os.environ["USER"]
+        or collection.metadata.get("username")
+        not in (os.environ.get("USER"), os.environ.get("USERNAME"), "DEFAULT_USER")
         or not collection.metadata.get("created-by") == "VectorCode"
     ):
         raise IndexError(
